@@ -18,7 +18,12 @@ fn main() {
          println!("send{} done:{:?}",i,t.elapsed());
       });
     }
+    println!("remain msg:{}", r.remain());
+    println!("sender num:{}", r.sender_num());
+    println!("receiver num:{}", r.receiver_num());
+
     sleep(Duration::from_secs(2));
+
     for _ in 0..1 {
         let rv = r.recv().unwrap();
         println!("recv = {}", rv);
